==> shellcheck-0.6.0-61-x86_64.pkg.tar.xz: usr/share/haskell/register/shellcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ShellCheck
version: 0.6.0
id: ShellCheck-0.6.0-AfCM1E9XkYw83pm2AOqtf3
key: ShellCheck-0.6.0-AfCM1E9XkYw83pm2AOqtf3
license: GPL-3.0-only
maintainer: vidar@vidarholen.net
author: Vidar Holen
homepage: https://www.shellcheck.net/
synopsis: Shell script analysis tool
description:
    The goals of ShellCheck are:
    .
    * To point out and clarify typical beginner'\''s syntax issues,
    that causes a shell to give cryptic error messages.
    .
    * To point out and clarify typical intermediate level semantic problems,
    that causes a shell to behave strangely and counter-intuitively.
    .
    * To point out subtle caveats, corner cases and pitfalls, that may cause an
    advanced user'\''s otherwise working script to fail under future circumstances.
category: Static Analysis
abi: 6fb9ca2affcbc61a38212b25a23aaa10
exposed: True
exposed-modules:
    ShellCheck.AST ShellCheck.ASTLib ShellCheck.Analytics
    ShellCheck.Analyzer ShellCheck.AnalyzerLib ShellCheck.Checker
    ShellCheck.Checks.Commands ShellCheck.Checks.ShellSupport
    ShellCheck.Data ShellCheck.Formatter.CheckStyle
    ShellCheck.Formatter.Format ShellCheck.Formatter.GCC
    ShellCheck.Formatter.JSON ShellCheck.Formatter.TTY
    ShellCheck.Interface ShellCheck.Parser ShellCheck.Regex
hidden-modules: Paths_ShellCheck
import-dirs: /usr/lib/ghc-8.6.4/site-local/ShellCheck-0.6.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/ShellCheck-0.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/ShellCheck-0.6.0
hs-libraries: HSShellCheck-0.6.0-AfCM1E9XkYw83pm2AOqtf3
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6
    aeson-1.4.2.0-3p7goNB3q4s1JbMrIJBuLL base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 directory-1.3.3.0 mtl-2.2.2
    parsec-3.1.13.0 process-1.6.5.0
    regex-tdfa-1.2.3.1-KcIcA5zjtfPBFphuPbNC37
haddock-interfaces: /usr/share/doc/shellcheck/html/ShellCheck.haddock
haddock-html: /usr/share/doc/shellcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> shellcheck-0.6.0-62-x86_64.pkg.tar.xz: usr/share/haskell/register/shellcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ShellCheck
version: 0.6.0
id: ShellCheck-0.6.0-BmvF9to6OpP3LlLHnaPkda
key: ShellCheck-0.6.0-BmvF9to6OpP3LlLHnaPkda
license: GPL-3.0-only
maintainer: vidar@vidarholen.net
author: Vidar Holen
homepage: https://www.shellcheck.net/
synopsis: Shell script analysis tool
description:
    The goals of ShellCheck are:
    .
    * To point out and clarify typical beginner'\''s syntax issues,
    that causes a shell to give cryptic error messages.
    .
    * To point out and clarify typical intermediate level semantic problems,
    that causes a shell to behave strangely and counter-intuitively.
    .
    * To point out subtle caveats, corner cases and pitfalls, that may cause an
    advanced user'\''s otherwise working script to fail under future circumstances.
category: Static Analysis
abi: a5ec06aa096953133f24219dfcccce64
exposed: True
exposed-modules:
    ShellCheck.AST ShellCheck.ASTLib ShellCheck.Analytics
    ShellCheck.Analyzer ShellCheck.AnalyzerLib ShellCheck.Checker
    ShellCheck.Checks.Commands ShellCheck.Checks.ShellSupport
    ShellCheck.Data ShellCheck.Formatter.CheckStyle
    ShellCheck.Formatter.Format ShellCheck.Formatter.GCC
    ShellCheck.Formatter.JSON ShellCheck.Formatter.TTY
    ShellCheck.Interface ShellCheck.Parser ShellCheck.Regex
hidden-modules: Paths_ShellCheck
import-dirs: /usr/lib/ghc-8.6.4/site-local/ShellCheck-0.6.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/ShellCheck-0.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/ShellCheck-0.6.0
hs-libraries: HSShellCheck-0.6.0-BmvF9to6OpP3LlLHnaPkda
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6
    aeson-1.4.2.0-Avxlg2iWl9mA2BcbnSAv1Y base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 directory-1.3.3.0 mtl-2.2.2
    parsec-3.1.13.0 process-1.6.5.0
    regex-tdfa-1.2.3.1-KcIcA5zjtfPBFphuPbNC37
haddock-interfaces: /usr/share/doc/shellcheck/html/ShellCheck.haddock
haddock-html: /usr/share/doc/shellcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
